import ChartPieIcon from "@icons/ChartPieIcon";
import ContactBookIcon from "@icons/ContactBookIcon";
import FlowArrowIcon from "@icons/FlowArrowIcon";
import LayoutIcon from "@icons/LayoutIcon";
import MegaphoneIcon from "@icons/MegaphoneIcon";
import QuestionIcon from "@icons/QuestionIcon";
import QuestionsMapIcon from "@icons/QuestionsMapIcon";

export const quizSetupSteps = [
  {
    stepperText: "Настройка стартовой страницы",
    sidebarText: "Стартовая страница",
    sidebarIcon: LayoutIcon,
  },
  {
    stepperText: "Задайте вопросы",
    sidebarText: "Вопросы",
    sidebarIcon: QuestionIcon,
  },
  {
    stepperText: "Настройте авторезультаты",
    sidebarText: "Результаты",
    sidebarIcon: ChartPieIcon,
  },
  // { stepperText: "Оценка графа карты вопросов", sidebarText: "Карта вопросов", sidebarIcon: QuestionsMapIcon },
  {
    stepperText: "Настройте форму контактов",
    sidebarText: "Форма контактов",
    sidebarIcon: ContactBookIcon,
  },
  {
    stepperText: "Установите quiz",
    sidebarText: "Установка quiz",
    sidebarIcon: FlowArrowIcon,
  },
  // { stepperText: "Запустите рекламу", sidebarText: "Запуск рекламы", sidebarIcon: MegaphoneIcon },
] as const;

export const maxQuizSetupSteps = quizSetupSteps.length;

export type QuizStartpageType = "standard" | "expanded" | "centered" | null;

export type QuizStartpageAlignType = "left" | "right" | "center";

export type QuizType = "quiz" | "form" | null;

export type QuizResultsType = true | null;

export interface QuizConfig {
  type: QuizType;
  noStartPage: boolean;
  startpageType: QuizStartpageType;
  results: QuizResultsType;
  haveRoot: string | null;
  theme:
    | "StandardTheme"
    | "StandardDarkTheme"
    | "PinkTheme"
    | "PinkDarkTheme"
    | "BlackWhiteTheme"
    | "OliveTheme"
    | "YellowTheme"
    | "GoldDarkTheme"
    | "PurpleTheme"
    | "BlueTheme"
    | "BlueDarkTheme";
  resultInfo: {
    when: "before" | "after" | "email";
    share: true | false;
    replay: true | false;
    theme: string;
    reply: string;
    replname: string;
  };
  startpage: {
    description: string;
    button: string;
    position: QuizStartpageAlignType;
    favIcon: string | null;
    logo: string | null;
    originalLogo: string | null;
    background: {
      type: null | "image" | "video";
      desktop: string | null;
      originalDesktop: string | null;
      mobile: string | null;
      originalMobile: string | null;
      video: string | null;
      cycle: boolean;
    };
  };
  formContact: {
    title: string;
    desc: string;
    fields: Record<FormContactFieldName, FormContactFieldData>;
    button: string;
  };
  info: {
    phonenumber: string;
    clickable: boolean;
    orgname: string;
    site: string;
    law?: string;
  };
  meta: string;
}

export type FormContactFieldName =
  | "name"
  | "email"
  | "phone"
  | "text"
  | "address";

type FormContactFieldData = {
  text: string;
  innerText: string;
  key: string;
  required: boolean;
  used: boolean;
};

export type FieldSettingsDrawerState = {
  field: FormContactFieldName | "all" | "";
  isEdit: boolean;
};

export const defaultQuizConfig: QuizConfig = {
  type: null,
  noStartPage: false,
  startpageType: null,
  results: null,
  haveRoot: null,
  theme: "StandardTheme",
  resultInfo: {
    when: "after",
    share: false,
    replay: false,
    theme: "",
    reply: "",
    replname: "",
  },
  startpage: {
    description: "",
    button: "",
    position: "left",
    favIcon: null,
    logo: null,
    originalLogo: null,
    background: {
      type: null,
      desktop: null,
      originalDesktop: null,
      mobile: null,
      originalMobile: null,
      video: null,
      cycle: false,
    },
  },
  info: {
    phonenumber: "",
    clickable: false,
    orgname: "",
    site: "",
    law: "",
  },
  formContact: {
    title: "",
    desc: "",
    fields: {
      name: {
        text: "",
        innerText: "",
        key: "",
        required: false,
        used: true,
      },
      email: {
        text: "",
        innerText: "",
        key: "",
        required: false,
        used: true,
      },
      phone: {
        text: "",
        innerText: "",
        key: "",
        required: false,
        used: true,
      },
      text: {
        text: "",
        innerText: "",
        key: "",
        required: false,
        used: false,
      },
      address: {
        text: "",
        innerText: "",
        key: "",
        required: false,
        used: false,
      },
    },
    button: "",
  },
  meta: "",
};
