import Box from "@mui/material/Box";
import {
  FormControl,
  SxProps,
  TextField,
  Theme,
  Typography,
} from "@mui/material";
import CustomTextField from "@ui_kit/CustomTextField";
import CustomCheckbox from "@ui_kit/CustomCheckbox";
import Button from "@mui/material/Button";
import * as React from "react";
import { useCurrentQuiz } from "@root/quizes/hooks";
import { updateQuiz } from "@root/quizes/actions";
import { FormContactFieldName } from "@model/quizSettings";

interface Props {
  outerContainerSx?: SxProps<Theme>;
  children?: React.ReactNode;
  defaultValue: FormContactFieldName;
  placeholderHelp: string;
  placeholderField: string;
  closeDrawer: () => void;
}

export default function NewFieldParent({
  closeDrawer,
  defaultValue,
  placeholderHelp,
  placeholderField,
  outerContainerSx: sx,
  children,
}: Props) {
  const quiz = useCurrentQuiz();

  if (!quiz) return null;

  return (
    <Box
      sx={{
        padding: "20px",
        display: "flex",
        flexDirection: "column",
        gap: "20px",
      }}
    >
      <Box sx={{ display: "flex", flexDirection: "column", gap: "15px" }}>
        <Typography>Подсказка</Typography>
        <CustomTextField
          onChange={({ target }) => {
            updateQuiz(quiz.id, (quiz) => {
              quiz.config.formContact.fields[defaultValue].text = target.value;
            });
          }}
          value={quiz.config.formContact.fields[defaultValue].text}
          placeholder={placeholderHelp}
          text={""}
        />
      </Box>
      <Box sx={{ display: "flex", flexDirection: "column", gap: "15px" }}>
        <Typography>Подсказка внутри поля</Typography>
        <CustomTextField
          onChange={({ target }) => {
            updateQuiz(quiz.id, (quiz) => {
              quiz.config.formContact.fields[defaultValue].innerText =
                target.value;
            });
          }}
          value={quiz.config.formContact.fields[defaultValue].innerText}
          placeholder={placeholderField}
          text={""}
        />
      </Box>
      <Box sx={{ display: "flex", flexDirection: "column", gap: "15px" }}>
        <Typography>Ключ</Typography>
        <TextField
          value={quiz.config.formContact.fields[defaultValue].key}
          onChange={({ target }) => {
            updateQuiz(quiz.id, (quiz) => {
              quiz.config.formContact.fields[defaultValue].key = target.value;
            });
          }}
          placeholder="text"
          sx={{
            "& .css-1d3z3hw-MuiOutlinedInput-notchedOutline": {
              border: "none",
            },
            "& .MuiInputBase-root": {
              height: "48px",
              borderRadius: "10px",
              backgroundColor: "#EEE4FC",
            },
          }}
        />
        <CustomCheckbox
          checked={quiz.config.formContact.fields[defaultValue].required}
          handleChange={({ target }) => {
            updateQuiz(quiz.id, (quiz) => {
              quiz.config.formContact.fields[defaultValue].required =
                target.checked;
            });
          }}
          label={"Обязательно к заполнению"}
        />
      </Box>
      {/* <Box>
                <Typography>Запрашивать на</Typography>
                <CustomCheckbox label={'Шаг 1'}/>
                <CustomCheckbox label={'Шаг 2'}/>
            </Box> */}
      {children}
      <Button
        onClick={() => {
          updateQuiz(quiz.id, (quiz) => {
            quiz.config.formContact.fields[defaultValue].used = true;
          });
          closeDrawer();
        }}
        variant="contained"
        sx={{ maxWidth: "125px" }}
      >
        Добавить
      </Button>
    </Box>
  );
}
