import { useEffect, useState } from "react";
import { Box, ThemeProvider, useTheme } from "@mui/material";

import { StartPageViewPublication } from "./StartPageViewPublication";
import { Question } from "./Question";
import { useCurrentQuiz } from "@root/quizes/hooks";
import { quizApi } from "@api/quiz";
import { setQuizes, updateQuiz } from "@root/quizes/actions";
import { useQuizStore } from "@root/quizes/store";

import type { AnyTypedQuizQuestion } from "../../model/questionTypes/shared";
import { useQuestionsStore } from "@root/questions/store";
import { setQuestions } from "@root/questions/actions";
import { questionApi } from "@api/question";
import { ApologyPage } from "./ApologyPage";
import { themesPublication } from "../../utils/themes/Publication/themePublication";

export const ViewPage = () => {
  const quiz = useCurrentQuiz();
  const { editQuizId } = useQuizStore();
  const { questions } = useQuestionsStore();
  const theme = useTheme();
  useEffect(() => {
    const getData = async () => {
      const quizes = await quizApi.getList();
      setQuizes(quizes);

      const questions = await questionApi.getList({ quiz_id: editQuizId });
      setQuestions(questions);
    };
    getData();
  }, []);
  useEffect(() => {
    setVisualStartPage(quiz?.config.noStartPage);
  }, [questions]);

  const [visualStartPage, setVisualStartPage] = useState<boolean>();

  useEffect(() => {
    const link = document.querySelector('link[rel="icon"]');

    if (link && quiz?.config.startpage.favIcon) {
      link.setAttribute("href", quiz.config.startpage.favIcon);
    }
  }, [quiz?.config.startpage.favIcon]);

  const filteredQuestions = (
    questions.filter(({ type }) => type) as AnyTypedQuizQuestion[]
  ).sort((previousItem, item) => previousItem.page - item.page);

  if (visualStartPage === undefined) return <></>;
  if (
    questions.length === 0 ||
    (questions.length === 1 && questions[0].type === "result")
  )
    return <ApologyPage message="Нет созданных вопросов" />;
  return (
    <ThemeProvider theme={themesPublication?.[quiz?.config.theme]}>
      <Box
        sx={{
          backgroundColor:
            quiz.config.startpageType === "expanded"
              ? undefined
              : theme.palette.background.default,
        }}
      >
        {!visualStartPage ? (
          <StartPageViewPublication setVisualStartPage={setVisualStartPage} />
        ) : (
          <Question questions={filteredQuestions} />
        )}
      </Box>
    </ThemeProvider>
  );
};
