import { Box, Typography, useTheme } from "@mui/material";

import { useQuizViewStore, updateAnswer } from "@root/quizView";

import type { QuizQuestionPage } from "../../../model/questionTypes/page";
import YoutubeEmbedIframe from "@ui_kit/StartPagePreview/YoutubeEmbedIframe";

type PageProps = {
  currentQuestion: QuizQuestionPage;
};

export const Page = ({ currentQuestion }: PageProps) => {
  const { answers } = useQuizViewStore();
  const { answer } =
    answers.find(
      ({ questionId }) => questionId === currentQuestion.content.id,
    ) ?? {};
  const theme = useTheme();

  return (
    <Box>
      <Typography
        variant="h5"
        sx={{ paddingBottom: "25px", color: theme.palette.text.primary }}
      >
        {currentQuestion.title}
      </Typography>
      <Typography color={theme.palette.text.primary}>
        {currentQuestion.content.text}
      </Typography>
      <Box
        sx={{
          display: "flex",
          flexDirection: "column",
          width: "100%",
          marginTop: "20px",
        }}
      >
        {currentQuestion.content.useImage ? (
          <Box
            sx={{
              borderRadius: "12px",
              border: "1px solid #9A9AAF",
              overflow: "hidden",
            }}
          >
            <img
              src={currentQuestion.content.back}
              alt=""
              style={{
                display: "block",
                width: "100%",
                height: "100%",
                objectFit: "contain",
              }}
            />
          </Box>
        ) : (
          <YoutubeEmbedIframe
            containerSX={{
              width: "100%",
              height: "calc( 100vh - 270px)",
              maxHeight: "80vh",
              objectFit: "contain",
            }}
            videoUrl={currentQuestion.content.video}
          />
        )}
      </Box>
    </Box>
  );
};
