import {
  Box,
  Typography,
  RadioGroup,
  FormControlLabel,
  Radio,
  useTheme,
  useMediaQuery,
} from "@mui/material";

import gag from "./gag.png";

import { useQuizViewStore, updateAnswer, deleteAnswer } from "@root/quizView";

import RadioCheck from "@ui_kit/RadioCheck";
import RadioIcon from "@ui_kit/RadioIcon";

import type { QuizQuestionVarImg } from "../../../model/questionTypes/varimg";
import { modes } from "../../../utils/themes/Publication/themePublication";
import { useCurrentQuiz } from "@root/quizes/hooks";

type VarimgProps = {
  currentQuestion: QuizQuestionVarImg;
};

export const Varimg = ({ currentQuestion }: VarimgProps) => {
  const { answers } = useQuizViewStore();
  const mode = modes;
  const quiz = useCurrentQuiz();
  const theme = useTheme();
  const isMobile = useMediaQuery(theme.breakpoints.down(650));
  const { answer } =
    answers.find(
      ({ questionId }) => questionId === currentQuestion.content.id,
    ) ?? {};
  const variant = currentQuestion.content.variants.find(
    ({ id }) => answer === id,
  );

  return (
    <Box>
      <Typography variant="h5" color={theme.palette.text.primary}>
        {currentQuestion.title}
      </Typography>
      <Box
        sx={{
          display: "flex",
          marginTop: "20px",
          flexDirection: isMobile ? "column-reverse" : undefined,
          gap: isMobile ? "30px" : undefined,
        }}
      >
        <RadioGroup
          name={currentQuestion.id}
          value={currentQuestion.content.variants.findIndex(
            ({ id }) => answer === id,
          )}
          sx={{
            display: "flex",
            flexWrap: "wrap",
            flexDirection: "row",
            justifyContent: "space-between",
            flexBasis: "100%",
          }}
        >
          <Box
            sx={{
              display: "flex",
              flexDirection: "column",
              width: "100%",
              gap: isMobile ? "20px" : undefined,
            }}
          >
            {currentQuestion.content.variants.map((variant, index) => (
              <FormControlLabel
                key={variant.id}
                sx={{
                  marginBottom: "15px",
                  borderRadius: "5px",
                  padding: "15px",
                  color: theme.palette.text.primary,
                  backgroundColor: mode[quiz.config.theme]
                    ? "white"
                    : theme.palette.background.default,
                  border: `1px solid`,
                  borderColor:
                    answer === variant.id
                      ? theme.palette.primary.main
                      : "#9A9AAF",
                  display: "flex",
                  margin: isMobile ? 0 : undefined,
                  "& .MuiFormControlLabel-label": {
                    wordBreak: "break-word",
                  },
                }}
                value={index}
                onClick={(event) => {
                  event.preventDefault();

                  updateAnswer(
                    currentQuestion.content.id,
                    currentQuestion.content.variants[index].id,
                  );

                  if (answer === currentQuestion.content.variants[index].id) {
                    deleteAnswer(currentQuestion.content.id);
                  }
                }}
                control={
                  <Radio
                    checkedIcon={
                      <RadioCheck color={theme.palette.primary.main} />
                    }
                    icon={<RadioIcon />}
                  />
                }
                label={variant.answer}
              />
            ))}
          </Box>
        </RadioGroup>
        {/* {(variant?.extendedText || currentQuestion.content.back) && ( */}
        <Box
          sx={{
            maxWidth: "450px",
            width: "100%",
            height: "450px",
            border: "1px solid #9A9AAF",
            borderRadius: "12px",
            overflow: "hidden",
            display: "flex",
            alignItems: "center",
            justifyContent: "center",
            backgroundColor: "#9A9AAF12",
            color: "#9A9AAF",
          }}
        >
          {answer ? (
            <img
              src={variant?.extendedText || gag}
              style={{ width: "100%", height: "100%", objectFit: "cover" }}
              alt=""
            />
          ) : currentQuestion.content.replText !== " " &&
            currentQuestion.content.replText.length > 0 ? (
            currentQuestion.content.replText
          ) : variant?.extendedText || isMobile ? (
            "Выберите вариант ответа ниже"
          ) : (
            "Выберите вариант ответа слева"
          )}
        </Box>
        {/* )} */}
      </Box>
    </Box>
  );
};
