import { useLayoutEffect, useState } from "react";
import { Box, Typography, useTheme } from "@mui/material";

import { CustomSlider } from "@ui_kit/CustomSlider";

import type { QuizQuestionNumber } from "model/questionTypes/number";
import CustomTextField from "@ui_kit/CustomTextField";
import { updateAnswer } from "@root/quizView";
import { modes } from "@utils/themes/Publication/themePublication";
import { useCurrentQuiz } from "@root/quizes/hooks";

interface Props {
  question: QuizQuestionNumber;
}

export default function Number({ question }: Props) {
  const [sliderValues, setSliderValues] = useState<number | number[]>(0);
  const theme = useTheme();
  const mode = modes;
  const quiz = useCurrentQuiz();
  const start = question.content.start;
  const min = parseInt(question.content.range.split("—")[0]);
  const max = parseInt(question.content.range.split("—")[1]);

  useLayoutEffect(() => {
    if (question.content.chooseRange) {
      setSliderValues([start, start + (max - start) / 2]);
    } else {
      setSliderValues(start);
    }
  }, [max, question.content.chooseRange, start]);

  return (
    <Box
      sx={{
        display: "flex",
        flexDirection: "column",
        gap: 1,
      }}
    >
      <Typography variant="h6" data-cy="question-title">
        {question.title}
      </Typography>
      <Box
        sx={{
          px: 2,
        }}
      >
        <CustomSlider
          className="cancel"
          value={sliderValues}
          onChange={(e, value) => {
            setSliderValues(value);
          }}
          min={min}
          max={max}
          defaultValue={start}
          valueLabelDisplay={"on"}
          step={question.content.step}
          sx={{
            color: theme.palette.primary.main,
            "& .MuiSlider-valueLabel": {
              background: theme.palette.primary.main,
            },
          }}
        />
        {!question.content.chooseRange && (
          <Box sx={{ mt: "30px", maxWidth: "80px" }}>
            <CustomTextField
              placeholder="0"
              value={sliderValues}
              sx={{
                borderColor: theme.palette.text.primary,
                "& .MuiInputBase-input": {
                  textAlign: "center",
                  backgroundColor: mode[quiz.config.theme]
                    ? "white"
                    : theme.palette.background.default,
                },
              }}
            />
          </Box>
        )}

        {question.content.chooseRange && (
          <Box
            sx={{
              mt: "30px",
              display: "flex",
              gap: "15px",
              alignItems: "center",
              "& .MuiFormControl-root": { width: "auto" },
            }}
          >
            <CustomTextField
              className="cancel"
              placeholder="0"
              value={sliderValues[0]}
              sx={{
                maxWidth: "80px",
                borderColor: theme.palette.text.primary,
                "& .MuiInputBase-input": {
                  textAlign: "center",
                  backgroundColor: mode[quiz.config.theme]
                    ? "white"
                    : theme.palette.background.default,
                },
              }}
            />
            <Typography color={theme.palette.text.primary}>до</Typography>
            <CustomTextField
              className="cancel"
              placeholder="0"
              value={sliderValues[1]}
              sx={{
                maxWidth: "80px",
                borderColor: theme.palette.text.primary,
                "& .MuiInputBase-input": {
                  textAlign: "center",
                  backgroundColor: mode[quiz.config.theme]
                    ? "white"
                    : theme.palette.background.default,
                },
              }}
            />
          </Box>
        )}
      </Box>
    </Box>
  );
}
