import { useState } from "react";
import {
  Box,
  FormControl,
  MenuItem,
  Select,
  SelectChangeEvent,
  Typography,
  useTheme,
} from "@mui/material";

import ArrowDownIcon from "@icons/ArrowDownIcon";

import type { QuizQuestionSelect } from "model/questionTypes/select";
interface Props {
  question: QuizQuestionSelect;
}

export default function Text({ question }: Props) {
  const theme = useTheme();
  const [selectValue, setSelectValue] = useState<string>("");
  const arrowDown = <ArrowDownIcon color={"currentColor"} />;
  function handleChange(event: SelectChangeEvent<string | null>) {
    setSelectValue((event.target as HTMLInputElement).value);
  }

  return (
    <Box
      sx={{
        display: "flex",
        flexDirection: "column",
        gap: 1,
      }}
    >
      <Typography variant="h6" data-cy="question-title">
        {question.title}
      </Typography>
      <FormControl
        className="cancel"
        fullWidth
        size="small"
        sx={{
          width: "100%",
          minWidth: "200px",
          height: "48px",
        }}
      >
        <Select
          id="category-select"
          variant="outlined"
          value={selectValue}
          placeholder={question.content.default}
          displayEmpty
          onChange={handleChange}
          data-cy="select"
          sx={{
            height: "48px",
            borderRadius: "8px",
            "& .MuiOutlinedInput-notchedOutline": {
              border: `1px solid ${theme.palette.primary.main} !important`,
            },
            "& .MuiSelect-icon": {
              color: theme.palette.primary.main,
            },
          }}
          MenuProps={{
            PaperProps: {
              sx: {
                mt: "8px",
                p: "4px",
                borderRadius: "8px",
                border: "1px solid #EEE4FC",
                backgroundColor: theme.palette.background.default,
                boxShadow: "0px 8px 24px rgba(210, 208, 225, 0.4)",
              },
            },
            MenuListProps: {
              sx: {
                py: 0,
                display: "flex",
                flexDirection: "column",
                gap: "8px",
                maxWidth: "330px",
                "& .Mui-selected": {
                  backgroundColor: theme.palette.background.default,
                  color: theme.palette.primary.main,
                },
              },
            },
          }}
          inputProps={{
            sx: {
              color: theme.palette.primary.main,
              display: "block",
              px: "9px",
              gap: "20px",
              paddingLeft: "10px",
              overflow: "hidden",
              textOverflow: "ellipsis",
              "& + input": !selectValue && {
                backgroundColor: theme.palette.background.default,
                border: "none",
                transform: "translateY(-50%)",
                top: "50%",
                opacity: 1,
                color: "#333",
                fontSize: "16px",
                overflow: "hidden",
                textOverflow: "ellipsis",
                paddingLeft: "10px",
                width: "88%",
              },
            },
          }}
          IconComponent={ArrowDownTheme}
        >
          {question.content.variants
            .filter(({ answer }) => answer)
            .map((variant) => (
              <MenuItem
                key={variant.answer}
                value={variant.answer}
                data-cy="select-option"
                sx={{
                  display: "flex",
                  alignItems: "center",
                  gap: "20px",
                  p: "4px",
                  borderRadius: "5px",
                  color: "#9A9AAF",
                  whiteSpace: "normal",
                }}
              >
                {variant.answer}
              </MenuItem>
            ))}
        </Select>
      </FormControl>
    </Box>
  );
}
export function ArrowDownTheme(props: any) {
  return (
    <Box
      {...props}
      sx={{
        top: "25% !important",
        height: "24px",
        width: "24px",
        display: "flex",
        alignItems: "center",
        justifyContent: "center",
      }}
    >
      <svg
        xmlns="http://www.w3.org/2000/svg"
        width="24"
        height="24"
        viewBox="0 0 24 24"
        fill="none"
      >
        <path
          d="M19.5 9L12 16.5L4.5 9"
          stroke={"currentColor"}
          strokeWidth="1.5"
          strokeLinecap="round"
          strokeLinejoin="round"
        />
      </svg>
    </Box>
  );
}
