import { ChangeEvent, useState } from "react";
import {
  Box,
  FormControl,
  FormControlLabel,
  FormLabel,
  Radio,
  RadioGroup,
  useRadioGroup,
  Tooltip,
  Typography,
  useTheme,
  Checkbox,
} from "@mui/material";

import InfoIcon from "@icons/InfoIcon";

import type { QuizQuestionVariant } from "model/questionTypes/variant";
import CustomRadio from "@ui_kit/CustomRadio";
import RadioCheck from "@ui_kit/RadioCheck";
import RadioIcon from "@ui_kit/RadioIcon";
import { modes } from "@utils/themes/Publication/themePublication";
import { useCurrentQuiz } from "@root/quizes/hooks";
import CheckboxIcon from "@icons/Checkbox";

interface Props {
  question: QuizQuestionVariant;
}

export default function Variant({ question }: Props) {
  const [value, setValue] = useState<string | null>(null);
  const theme = useTheme();
  const mode = modes;
  const quiz = useCurrentQuiz();
  const handleChange = (event: ChangeEvent<HTMLInputElement>) => {
    setValue((event.target as HTMLInputElement).value);
  };

  return (
    <FormControl className="cancel" fullWidth>
      <FormLabel
        id="quiz-question-radio-group"
        data-cy="question-title"
        sx={{
          color: theme.palette.text.primary,
          marginBottom: "20px",
          fontSize: "24px",
          fontWeight: 500,
        }}
      >
        {question.title}
      </FormLabel>
      <RadioGroup
        className="cancel"
        aria-labelledby="quiz-question-radio-group"
        value={value}
        onChange={handleChange}
        sx={{
          flexDirection: "row",
          gap: "20px",
        }}
      >
        {question.content.variants
          .filter(({ answer }) => answer)
          .map((variant, index) => (
            <FormControlLabel
              className="cancel"
              key={index}
              value={variant.answer}
              data-cy="variant-answer"
              labelPlacement="start"
              sx={{
                borderRadius: "12px",
                border:
                  value == variant.answer
                    ? `1px solid ${theme.palette.primary.main}`
                    : "1px solid #9A9AAF",
                padding: "20px",
                justifyContent: "space-between",
                maxWidth: "685px",
                backgroundColor: mode[quiz.config.theme]
                  ? "white"
                  : theme.palette.background.default,
                width: "100%",
                margin: 0,
                // "& .MuiFormControlLabel-label": {
                //     overflow: "hidden",
                // }
              }}
              control={
                question.content.multi ? (
                  <Checkbox
                    checkedIcon={
                      <CheckboxIcon
                        checked
                        color={theme.palette.primary.main}
                      />
                    }
                    icon={<CheckboxIcon />}
                  />
                ) : (
                  <Radio
                    inputProps={{
                      "data-cy": "variant-radio",
                    }}
                    checkedIcon={
                      <RadioCheck color={theme.palette.primary.main} />
                    }
                    icon={<RadioIcon />}
                  />
                )
              }
              label={
                <Box sx={{ display: "flex", alignItems: "center", gap: 2 }}>
                  <Typography
                    color={theme.palette.text.primary}
                    sx={{
                      wordBreak: "break-word",
                    }}
                  >
                    {variant.answer}
                  </Typography>
                  {variant.hints && (
                    <Tooltip title={variant.hints} placement="right">
                      <Box>
                        <InfoIcon />
                      </Box>
                    </Tooltip>
                  )}
                </Box>
              }
            />
          ))}
      </RadioGroup>
    </FormControl>
  );
}
